Documentation
=============

This is the documentation for nexoclom.
Monte Carlo model of neutral clouds and exospheres

.. toctree::
  :maxdepth: 2

  nexoclom/Input
  nexoclom/Output
  nexoclom/ModelResult
  nexoclom/LOSResult
  nexoclom/configure_model
  nexoclom/outline

Input Files
-----------

The inputs for a model run are defined in an plain text file with lines in the
form: ::

    category.parameter = setting

A description of everything that can go into an input file is at
:doc:`nexoclom/inputfiles`.
